# Shutter pacakge
This is a simple realization of optical shutter, which is purchased from TaoBao
Here mainly including 5 methods: setOpenMode, setControlMode, setOn, setOff and setWindowOpen
While the most used is the methods: setOn and setOff
## setOn
## setOff